let path = require('path');
let webpack = require('webpack');
// process.traceDeprecation = true
process.noDeprecation = true

let config = {
    entry: [
        `${light.config.dist}/view/index.js`,
        `${light.config.dist}/app.js`,
    ],
    output: {
        path: light.config.dist,
        filename: 'app.js'
    },
    module: {
        rules: [
            {
                test: /\.vue$/,
                loader: 'vue-loader',
                options: {
                    loaders: {
                        js:"babel-loader?presets=es2015"
                    }
                    // other vue-loader options go here
                }
            },
            // {
            //     test: /\.js$/,
            //     loader: 'babel-loader',
            //     exclude: /node_modules/,
            //     options: {
            //         plugins: ['syntax-dynamic-import'],
            //         presets: ['env']
            //     }
            // },
            {
                test: /\.(js|vue)/,
                loader: 'string-replace-loader',
                query: {
                    search: '__ENV__',
                    replace: require("./env")(light.options.env||'default'),
                    flag:"g"
                }
            },
            {
                test: /\.js$/,
                // exclude: /(node_modules|bower_components)/,
                use: {
                    loader: 'babel-loader',
                    options: {
                        presets: ['es2015'],
                        plugins: ['syntax-dynamic-import'],
                        compact:'false'
                    }
                }
            },
            {
                test: /\.(png|jpg|gif|svg)$/,
                loader: 'file-loader',
                options: {
                    name: '[name].[ext]?[hash]'
                }
            }
        ]
    },
    resolve: {
        extensions: ['.js', '.vue', '.json'],
        modules:[`${__dirname}/node_modules`,"lib/node_modules","lib"],
        alias:{
            "light":`olight/dist/olight.js`,
            'vue': "olight/vuejs.js"
        }
    },
    plugins: [
        new webpack.DefinePlugin({
            'process.env.NODE_ENV': JSON.stringify(process.env.NODE_ENV)
        })
    ]
};

if(process.env.NODE_ENV==="dev"){
    config.entry = ['webpack-hot-middleware/client?path=/__webpack_hmr&timeout=20000'].concat(config.entry);
    config.plugins = config.plugins.concat([
        new webpack.HotModuleReplacementPlugin({
            multiStep: true,
        }),
        // new webpack.NoEmitOnErrorsPlugin()
        ]
    );
}

if(light.util.existsSync(`lib/light.build.js`)){
    light.require = require;
    config = require(`lib/light.build.js`)(light,config)
}


module.exports = config;
